@@ -128,6 +128,7 @@ SITES = {
     'youtube'          : 'youtube',
     'zhanqi'           : 'zhanqi',
     'zhibo'            : 'zhibo',
+    'zhihu'            : 'zhihu',
 }
 
 dry_run = False
@@ -272,7 +273,15 @@ def matchall(text, patterns):
 def launch_player(player, urls):
     import subprocess
     import shlex
-    subprocess.call(shlex.split(player) + list(urls))
+    if (sys.version_info >= (3, 3)):
+        import shutil
+        exefile=shlex.split(player)[0]
+        if shutil.which(exefile) is not None:
+            subprocess.call(shlex.split(player) + list(urls))
+        else:
+            log.wtf('[Failed] Cannot find player "%s"' % exefile)
+    else:
+        subprocess.call(shlex.split(player) + list(urls))
 
 
 def parse_query_param(url, param):
