@@ -211,7 +211,7 @@ class VideoExtractor():
                 ext = self.dash_streams[stream_id]['container']
                 total_size = self.dash_streams[stream_id]['size']
 
-            if ext == 'm3u8':
+            if ext == 'm3u8' or ext == 'm4a':
                 ext = 'mp4'
 
             if not urls:
